@@ -24,7 +24,7 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <wpe/renderer-backend-egl.h>
+#include "../include/wpe/renderer-backend-egl.h"
 
 #include "loader-private.h"
 #include "renderer-backend-egl-private.h"
@@ -138,6 +138,13 @@ wpe_renderer_backend_egl_target_frame_rendered(struct wpe_renderer_backend_egl_t
     target->base.interface->frame_rendered(target->base.interface_data);
 }
 
+void
+wpe_renderer_backend_egl_target_deinitialize(struct wpe_renderer_backend_egl_target* target)
+{
+    if (target->base.interface->deinitialize)
+        target->base.interface->deinitialize(target->base.interface_data);
+}
+
 struct wpe_renderer_backend_egl_offscreen_target*
 wpe_renderer_backend_egl_offscreen_target_create()
 {
