@@ -27,7 +27,7 @@
 #ifndef wpe_view_backend_private_h
 #define wpe_view_backend_private_h
 
-#include <wpe/view-backend.h>
+#include "../include/wpe/view-backend.h"
 
 #ifdef __cplusplus
 extern "C" {
